#[non_exhaustive]pub enum TryReserveError {
CapacityOverflow,
AllocError {
layout: Layout,
},
}Expand description
An error that can occur during a try_reserve method.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CapacityOverflow
The amount of memory that we would need to allocate would have been greater than the maximum (typically `isize::MAX).
AllocError
We were unable to allocate memory to grow the table or set.