Module weak_value_hash_map

Module weak_value_hash_map 

A hash map where the values are held by weak pointers.

Re-exports

pub use super::WeakValueHashMap;

Structs

Drain
An iterator that consumes the values of a weak hash map, leaving it empty.
ExtractIf
An iterator that removes members that match a given predicate.
IntoIter
An iterator that consumes a weak hash map, leaving it empty.
IntoKeys
A consuming iterator that returns only keys, and discards values.
IntoValues
A consuming iterator that returns only values, and discards keys.
Iter
An iterator over the keys and values of the weak hash map.
Keys
An iterator over the keys of the weak hash map.
OccupiedEntry
An occupied entry, which can be removed, modified, or viewed.
VacantEntry
A vacant entry, which can be inserted in or viewed.
Values
An iterator over the values of the weak hash map.

Enums

Entry
Represents an entry in the table which may be occupied or vacant.