Struct weak_table::weak_value_hash_map::OccupiedEntry [] [src]

pub struct OccupiedEntry<'a, K: 'a, V: 'a + WeakElement> { /* fields omitted */ }

An occupied entry, which can be removed or viewed.

Methods

impl<'a, K, V: WeakElement> OccupiedEntry<'a, K, V>
[src]

[src]

Gets a reference to the key held by the entry.

[src]

Takes ownership of the key and value from the map.

[src]

Gets a reference to the value in the entry.

[src]

Gets a copy of the strong value reference stored in the entry.

[src]

Replaces the value in the entry with the given value, returning the old value.

[src]

Removes the entry, returning the value.