pub struct VacantEntry<'a, K: 'a, V: 'a + WeakElement>(/* private fields */);Expand description
A vacant entry, which can be inserted in or viewed.
Implementations
Sourceimpl<'a, K, V: WeakElement> VacantEntry<'a, K, V>
impl<'a, K, V: WeakElement> VacantEntry<'a, K, V>
Sourcepub fn key(&self) -> &K
pub fn key(&self) -> &K
Gets a reference to the key that would be used when inserting a
value through the VacantEntry.
O(1) time
Sourcepub fn insert(self, value: V::Strong) -> V::Strong
pub fn insert(self, value: V::Strong) -> V::Strong
Inserts the value into the map, returning the same value.
O(1) time
Sourcepub fn insert_entry(self, value: V::Strong) -> OccupiedEntry<'a, K, V>
pub fn insert_entry(self, value: V::Strong) -> OccupiedEntry<'a, K, V>
Inserts the key and value into the map, returning an OccupiedEntry.
O(1) time