A hash set where the elements are held by weak pointers and compared by pointer.
Re-exports
pub use super::PtrWeakHashSet;
Structs
- Difference
- An iterator to return the difference of two sets.
- Drain
- A draining iterator over the elements of a set.
- Extract
If - An iterator that removes members that match a given predicate.
- Intersection
- An iterator to return the intersection of two sets.
- Into
Iter - An iterator over the elements of a set.
- Iter
- An iterator over the elements of a set.
- Symmetric
Difference - An iterator to return the symmetric difference of two sets.
- Union
- An iterator to return the union of two sets.