pub struct PtrWeakKeyHashMap<K, V, S = RandomState>(/* private fields */);Expand description
A hash map with weak keys, hashed on key pointer.
When a weak pointer expires, its mapping is lazily removed.
Examples
use weak_table::PtrWeakKeyHashMap;
use std::rc::{Rc, Weak};
type Table = PtrWeakKeyHashMap<Weak<str>, usize>;
let mut map = Table::new();
let a = Rc::<str>::from("hello");
let b = Rc::<str>::from("hello");
map.insert(a.clone(), 5);
assert_eq!( map.get(&a), Some(&5) );
assert_eq!( map.get(&b), None );
map.insert(b.clone(), 7);
assert_eq!( map.get(&a), Some(&5) );
assert_eq!( map.get(&b), Some(&7) );Implementations
Sourceimpl<K, V> PtrWeakKeyHashMap<K, V, RandomState>
impl<K, V> PtrWeakKeyHashMap<K, V, RandomState>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty `PtrWeakKeyHashMap with the given capacity.
O(n) time
Sourceimpl<K, V, S: BuildHasher> PtrWeakKeyHashMap<K, V, S>
impl<K, V, S: BuildHasher> PtrWeakKeyHashMap<K, V, S>
Sourcepub fn with_hasher(hash_builder: S) -> Self
pub fn with_hasher(hash_builder: S) -> Self
Creates an empty `PtrWeakKeyHashMap with the given hasher.
O(n) time
Sourcepub fn with_capacity_and_hasher(capacity: usize, hash_builder: S) -> Self
pub fn with_capacity_and_hasher(capacity: usize, hash_builder: S) -> Self
Creates an empty `PtrWeakKeyHashMap with the given capacity and hasher.
O(n) time
Sourceimpl<K, V, S> PtrWeakKeyHashMap<K, V, S>
impl<K, V, S> PtrWeakKeyHashMap<K, V, S>
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of elements the map can hold without reallocating.
O(1) time
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns an over-approximation of the number of elements.
(This is an over-approximation because it includes expired elements.)
O(1) time
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Is the map empty?
Note that this may return false even if all elements have expired, if they haven’t been collected yet.
O(1) time
Sourcepub fn load_factor(&self) -> f32
pub fn load_factor(&self) -> f32
Returns proportion of buckets that are used.
This is an over-approximation because of expired elements.
O(1) time
Sourceimpl<K: WeakElement, V, S: BuildHasher> PtrWeakKeyHashMap<K, V, S>
impl<K: WeakElement, V, S: BuildHasher> PtrWeakKeyHashMap<K, V, S>
Sourcepub fn remove_expired(&mut self)
pub fn remove_expired(&mut self)
Removes all mappings whose keys have expired.
O(n) time
Sourcepub fn reserve(&mut self, additional_capacity: usize)
pub fn reserve(&mut self, additional_capacity: usize)
Reserves room for additional elements.
This method ensures that at least additional_capacity insertions
may be performed without reallocating.
O(n) time
Sourcepub fn try_reserve(
&mut self,
additional_capacity: usize,
) -> Result<(), TryReserveError>
pub fn try_reserve( &mut self, additional_capacity: usize, ) -> Result<(), TryReserveError>
Tries to reserve room for additional mappings.
If this method succeeds, then at least additional_capacity insertions
may be performed without reallocating further.
O(n) time
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity to the minimum to hold the current number of mappings.
O(n) time
Sourcepub fn shrink_to(&mut self, min_capacity: usize)
pub fn shrink_to(&mut self, min_capacity: usize)
Shrinks the capacity to hold no fewer than min_capacity mappings.
May remove expired items if necessary.
Does nothing if the current capacity is already at min_capacity or below.
O(n) time
Sourcepub fn entry(&mut self, key: K::Strong) -> Entry<'_, ByPtr<K>, V>
pub fn entry(&mut self, key: K::Strong) -> Entry<'_, ByPtr<K>, V>
The proportion of buckets that Gets the requested entry.
expected O(1) time; worst-case O(p) time
Sourcepub fn get(&self, key: &K::Strong) -> Option<&V>
pub fn get(&self, key: &K::Strong) -> Option<&V>
Returns a reference to the value corresponding to the key.
Returns None if no matching key is found.
expected O(1) time; worst-case O(p) time
Sourcepub fn contains_key(&self, key: &K::Strong) -> bool
pub fn contains_key(&self, key: &K::Strong) -> bool
Returns true if the map contains the specified key.
expected O(1) time; worst-case O(p) time
Sourcepub fn get_mut(&mut self, key: &K::Strong) -> Option<&mut V>
pub fn get_mut(&mut self, key: &K::Strong) -> Option<&mut V>
Returns a mutable reference to the value corresponding to the key.
Returns None if no matching key is found.
expected O(1) time; worst-case O(p) time
Sourcepub fn get_disjoint_mut<const N: usize>(
&mut self,
ks: [&K::Strong; N],
) -> [Option<&mut V>; N]
pub fn get_disjoint_mut<const N: usize>( &mut self, ks: [&K::Strong; N], ) -> [Option<&mut V>; N]
Looks up mutable references to the values corresponding to several keys at a time.
(Because of borrowing rules, Rust doesn’t allow you to call get_mut() again
while the result of a previous get_mut() is still live. This method exists
to work around that limitation.)
Only one mutable reference can exist to any given value at a time. Therefore, all keys must refer to different values, or this method will panic.
expected O(1 N^2) time; worst-case O(p N^2) time,
where N is the length of the array.
Panics
Panics if any keys refer to the same value.
Sourcepub fn insert(&mut self, key: K::Strong, value: V) -> Option<V>
pub fn insert(&mut self, key: K::Strong, value: V) -> Option<V>
Unconditionally inserts the value, returning the old value if already present. Does not replace the key.
expected O(1) time; worst-case O(p) time
Sourcepub fn remove(&mut self, key: &K::Strong) -> Option<V>
pub fn remove(&mut self, key: &K::Strong) -> Option<V>
Removes the entry with the given key, if it exists, and returns the value.
expected O(1) time; worst-case O(p) time
Sourcepub fn retain<F>(&mut self, f: F)
pub fn retain<F>(&mut self, f: F)
Removes all mappings not satisfying the given predicate.
Also removes any expired mappings.
O(n) time
Sourcepub fn submap_with<F, S1, V1>(
&self,
other: &PtrWeakKeyHashMap<K, V1, S1>,
value_equal: F,
) -> bool
pub fn submap_with<F, S1, V1>( &self, other: &PtrWeakKeyHashMap<K, V1, S1>, value_equal: F, ) -> bool
Is this map a submap of the other, using the given value comparison.
In particular, all the keys of self must be in other and the values must compare true with value_equal.
expected O(n) time; worst-case O(nq) time (where n is
self.capacity() and q is the length of the probe sequences
in other)
Sourcepub fn is_submap<V1, S1>(&self, other: &PtrWeakKeyHashMap<K, V1, S1>) -> boolwhere
V: PartialEq<V1>,
S1: BuildHasher,
pub fn is_submap<V1, S1>(&self, other: &PtrWeakKeyHashMap<K, V1, S1>) -> boolwhere
V: PartialEq<V1>,
S1: BuildHasher,
Is self a submap of other?
expected O(n) time; worst-case O(nq) time (where n is
self.capacity() and q is the length of the probe sequences
in other)
Sourcepub fn domain_is_subset<V1, S1>(
&self,
other: &PtrWeakKeyHashMap<K, V1, S1>,
) -> boolwhere
S1: BuildHasher,
pub fn domain_is_subset<V1, S1>(
&self,
other: &PtrWeakKeyHashMap<K, V1, S1>,
) -> boolwhere
S1: BuildHasher,
Are the keys of self a subset of the keys of other?
expected O(n) time; worst-case O(nq) time (where n is
self.capacity() and q is the length of the probe sequences
in other)
Sourceimpl<K: WeakElement, V, S> PtrWeakKeyHashMap<K, V, S>
impl<K: WeakElement, V, S> PtrWeakKeyHashMap<K, V, S>
Sourcepub fn iter(&self) -> Iter<'_, ByPtr<K>, V> ⓘ
pub fn iter(&self) -> Iter<'_, ByPtr<K>, V> ⓘ
Gets an iterator over the keys and values.
O(1) time
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, ByPtr<K>, V> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, ByPtr<K>, V> ⓘ
Gets an iterator over the keys and mutable values.
O(1) time
Sourcepub fn values_mut(&mut self) -> ValuesMut<'_, ByPtr<K>, V> ⓘ
pub fn values_mut(&mut self) -> ValuesMut<'_, ByPtr<K>, V> ⓘ
Gets an iterator over the mutable values.
O(1) time
Sourcepub fn drain(&mut self) -> Drain<'_, ByPtr<K>, V> ⓘ
pub fn drain(&mut self) -> Drain<'_, ByPtr<K>, V> ⓘ
Gets a draining iterator, which removes all the values but retains the storage.
O(1) time (and O(n) time to dispose of the result)
Sourcepub fn into_keys(self) -> IntoKeys<ByPtr<K>, V> ⓘ
pub fn into_keys(self) -> IntoKeys<ByPtr<K>, V> ⓘ
Returns an iterator that owns and consumes this map, returning the keys in the map.
O(1)
Sourcepub fn into_values(self) -> IntoValues<ByPtr<K>, V> ⓘ
pub fn into_values(self) -> IntoValues<ByPtr<K>, V> ⓘ
Returns an iterator that owns and consumes this map, returning the keys in the map.
O(1)
Sourcepub fn extract_if<'a, F>(&'a mut self, f: F) -> ExtractIf<'a, ByPtr<K>, V, F> ⓘ
pub fn extract_if<'a, F>(&'a mut self, f: F) -> ExtractIf<'a, ByPtr<K>, V, F> ⓘ
Gets an iterator that removes and returns elements matching a given predicate.
Expired elements are also removed.
If this iterator is dropped before it is completed, then no further
elements are removed.
(This is in contrast to the behavior of drain).
O(1) time