pub struct WeakValueHashMap<K, V, S = RandomState>(/* private fields */);Expand description
A hash map with weak values.
When a weak pointer expires, its mapping is lazily removed.
Implementations
Sourceimpl<K, V> WeakValueHashMap<K, V, RandomState>
impl<K, V> WeakValueHashMap<K, V, RandomState>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty WeakValueHashMap with the given capacity.
O(n) time
Sourceimpl<K, V, S: BuildHasher> WeakValueHashMap<K, V, S>
impl<K, V, S: BuildHasher> WeakValueHashMap<K, V, S>
Sourcepub fn with_hasher(hash_builder: S) -> Self
pub fn with_hasher(hash_builder: S) -> Self
Creates an empty WeakValueHashMap with the given hasher.
O(n) time
Sourcepub fn with_capacity_and_hasher(capacity: usize, hash_builder: S) -> Self
pub fn with_capacity_and_hasher(capacity: usize, hash_builder: S) -> Self
Creates an empty WeakValueHashMap with the given capacity and hasher.
O(n) time
Sourceimpl<K, V, S> WeakValueHashMap<K, V, S>
impl<K, V, S> WeakValueHashMap<K, V, S>
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of elements the map can hold without reallocating.
O(1) time
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns an over-approximation of the number of elements.
(This is an over-approximation because it includes expired elements.)
O(1) time
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Is the map empty?
Note that this may return false even if all elements have expired, if they haven’t been collected yet.
O(1) time
Sourcepub fn load_factor(&self) -> f32
pub fn load_factor(&self) -> f32
Returns proportion of buckets that are used.
This is an over-approximation because of expired elements.
O(1) time
Sourceimpl<K: Eq + Hash, V: WeakElement, S: BuildHasher> WeakValueHashMap<K, V, S>
impl<K: Eq + Hash, V: WeakElement, S: BuildHasher> WeakValueHashMap<K, V, S>
Sourcepub fn remove_expired(&mut self)
pub fn remove_expired(&mut self)
Removes all mappings whose keys have expired.
O(n) time
Sourcepub fn reserve(&mut self, additional_capacity: usize)
pub fn reserve(&mut self, additional_capacity: usize)
Reserves room for additional elements.
This method ensures that at least additional_capacity insertions
may be performed without reallocating.
O(n) time
Sourcepub fn try_reserve(
&mut self,
additional_capacity: usize,
) -> Result<(), TryReserveError>
pub fn try_reserve( &mut self, additional_capacity: usize, ) -> Result<(), TryReserveError>
Tries to reserve room for additional mappings.
If this method succeeds, then at least additional_capacity insertions
may be performed without reallocating further.
O(n) time
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity to the minimum to hold the current number of mappings.
O(n) time
Sourcepub fn shrink_to(&mut self, min_capacity: usize)
pub fn shrink_to(&mut self, min_capacity: usize)
Shrinks the capacity to hold no fewer than min_capacity mappings.
May remove expired items if necessary.
Does nothing if the current capacity is already at min_capacity or below.
O(n) time
Sourcepub fn entry(&mut self, key: K) -> Entry<'_, K, V>
pub fn entry(&mut self, key: K) -> Entry<'_, K, V>
Gets the requested entry.
expected O(1) time; worst-case O(p) time
Sourcepub fn get<Q>(&self, key: &Q) -> Option<V::Strong>
pub fn get<Q>(&self, key: &Q) -> Option<V::Strong>
Returns a reference to the value corresponding to the key.
Returns None if no matching key is found.
expected O(1) time; worst-case O(p) time
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains the specified key.
expected O(1) time; worst-case O(p) time
Sourcepub fn insert(&mut self, key: K, value: V::Strong) -> Option<V::Strong>
pub fn insert(&mut self, key: K, value: V::Strong) -> Option<V::Strong>
Unconditionally inserts the value, returning the old value if already present.
Like std::collections::HashMap, this does not replace the key if occupied.
expected O(1) time; worst-case O(p) time
Sourcepub fn remove<Q>(&mut self, key: &Q) -> Option<V::Strong>
pub fn remove<Q>(&mut self, key: &Q) -> Option<V::Strong>
Removes the entry with the given key, if it exists, and returns the value.
expected O(1) time; worst-case O(p) time
Sourcepub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V::Strong)>
pub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V::Strong)>
Removes the entry with the given key, if it exists, and returns both the key and value.
expected O(1) time; worst-case O(p) time
Sourcepub fn retain<F>(&mut self, f: F)
pub fn retain<F>(&mut self, f: F)
Removes all mappings not satisfying the given predicate.
Also removes any expired mappings.
O(n) time
Sourcepub fn is_submap_with<F, S1, V1>(
&self,
other: &WeakValueHashMap<K, V1, S1>,
value_equal: F,
) -> bool
pub fn is_submap_with<F, S1, V1>( &self, other: &WeakValueHashMap<K, V1, S1>, value_equal: F, ) -> bool
Is this map a submap of the other, using the given value comparison.
In particular, all the keys of self must be in other and the values must compare
true with value_equal.
expected O(n) time; worst-case O(nq) time (where n is
self.capacity() and q is the length of the probe sequences
in other)
Sourcepub fn is_submap<V1, S1>(&self, other: &WeakValueHashMap<K, V1, S1>) -> bool
pub fn is_submap<V1, S1>(&self, other: &WeakValueHashMap<K, V1, S1>) -> bool
Is self a submap of other?
expected O(n) time; worst-case O(nq) time (where n is
self.capacity() and q is the length of the probe sequences
in other)
Sourcepub fn domain_is_subset<V1, S1>(
&self,
other: &WeakValueHashMap<K, V1, S1>,
) -> boolwhere
V1: WeakElement,
S1: BuildHasher,
pub fn domain_is_subset<V1, S1>(
&self,
other: &WeakValueHashMap<K, V1, S1>,
) -> boolwhere
V1: WeakElement,
S1: BuildHasher,
Are the keys of self a subset of the keys of other?
expected O(n) time; worst-case O(nq) time (where n is
self.capacity() and q is the length of the probe sequences
in other)
Sourceimpl<K, V: WeakElement, S> WeakValueHashMap<K, V, S>
impl<K, V: WeakElement, S> WeakValueHashMap<K, V, S>
Sourcepub fn drain(&mut self) -> Drain<'_, K, V> ⓘ
pub fn drain(&mut self) -> Drain<'_, K, V> ⓘ
Gets a draining iterator, which removes all the values but retains the storage.
O(1) time (and O(n) time to dispose of the result)
Sourcepub fn into_keys(self) -> IntoKeys<K, V> ⓘ
pub fn into_keys(self) -> IntoKeys<K, V> ⓘ
Returns an iterator that owns and consumes this map, returning the keys in the map.
O(1)
Sourcepub fn into_values(self) -> IntoValues<K, V> ⓘ
pub fn into_values(self) -> IntoValues<K, V> ⓘ
Returns an iterator that owns and consumes this map, returning the keys in the map.
O(1)
Sourcepub fn extract_if<'a, F>(&'a mut self, f: F) -> ExtractIf<'a, K, V, F> ⓘ
pub fn extract_if<'a, F>(&'a mut self, f: F) -> ExtractIf<'a, K, V, F> ⓘ
Gets an iterator that removes and returns elements matching a given predicate.
Expired elements are also removed.
If this iterator is dropped before it is completed, then no further
elements are removed.
(This is in contrast to the behavior of drain).
O(1) time